/**
 * @file
 * The widget library.
 */

(function ($, Drupal, drupalSettings, client) {

  'use strict';

  /**
   * Object constructor.
   */
  let OidcMcpfToolbar = function () {
    this.inited = false;
    this.settings = drupalSettings.oidcMcpfToolbar;
    this.widget = null;
    this.session = null;
  };

  /**
   * Invoked after after loading the initial page and after each AJAX request.
   *
   * @param context
   *   The DOM context.
   * @param settings
   *   Object with additional settings.
   */
  OidcMcpfToolbar.prototype.attach = function (context, settings)  {
    if (!this.inited) {
      this.inited = true;
      let instance = this;

      client.capture(function (widget) {
        if (widget.getPluginTypeId() === 'global_header') {
          widget.getExtension('citizen_profile.session').then(function (session) {
            instance.widget = widget;
            instance.session = session;
            instance.initSession();
          });

          $('body').addClass('oidc-mcpf-toolbar');
        }
      });
    }
  };

  /**
   * Initialize the session.
   */
  OidcMcpfToolbar.prototype.initSession = function() {
    // Configure the session.
    this.session.configure(this.settings.session);

    // Extend the session on certain events.
    let instance = this;
    let eventNames = [
      'mousedown',
      'mousemove',
      'mousewheel',
      'DOMMouseScroll',
      'scroll',
      'wheel',
      'keydown',
      'keypress',
      'touchmove',
      'touchstart'
    ];

    for (let i = 0; i < eventNames.length; i++) {
      window.addEventListener(eventNames[i], function() {
        instance.session.extend();
      });
    }
  };

  /*
   * Attach ourself as a behaviour.
   */
  Drupal.behaviors.oidcMcpfToolbar = new OidcMcpfToolbar();

})(jQuery, Drupal, drupalSettings, vl.widget.client);
